import pathlib
import datetime
from . import logging
import os

def cache_file_exists(cache_file, cache_minutes):    
    if os.path.exists(cache_file):
        #https://stackoverflow.com/questions/237079/how-to-get-file-creation-and-modification-date-times
        m_dt = datetime.datetime.fromtimestamp(pathlib.Path(cache_file).stat().st_mtime, tz=datetime.timezone.utc) + datetime.timedelta(hours=9)
        logging.debug(m_dt)
        logging.debug(type(m_dt))
    
        #https://stackoverflow.com/questions/15307623/cant-compare-naive-and-aware-datetime-now-challenge-datetime-end
        now_dt = datetime.datetime.now(datetime.timezone.utc) + datetime.timedelta(hours=9)
        cache_minutes_dt = now_dt - datetime.timedelta(minutes=5)
        logging.debug(cache_minutes_dt)
        logging.debug(type(cache_minutes_dt))

        if m_dt > cache_minutes_dt: #캐시에서 가져오기
            return True
        else: #새로 가져오기
            return False
    return False 

if __name__ == "__main__":
    level = logging.DEBUG
    #level = logging.INFO
    #level = logging.ERROR
    logging.basic_config(level)
    
    print(cache_file_exists("cache.json", 10))



import json
import os

def load_config_from_file(file):
    if os.path.exists(file):
        with open(file, encoding="utf8") as f:
            config = json.load(f)
        return config
    return None

def load_config_from_text(text):
    config = json.loads(text)
    return config

def save_config_dict(file, dict):
    with open(file, "w", encoding='utf8') as f:
        json.dump(dict, f, indent=4)

def save_config_text(file, text):
    with open(file, "w", encoding='utf8') as f:
        f.write(text)



'''
https://pyob.oxyry.com/
'''
import requests
import urllib.parse
import argparse 
import json
from . import logging
from pathlib import Path
import os

def obfuscate_code(code):
    logging.debug("===")
    logging.debug(code)
    code = code.strip()
	
	#https://m.blog.naver.com/wideeyed/221586482884
    data = {"append_source":False,"remove_docstrings":True,"rename_nondefault_parameters":True,"rename_default_parameters":False,"preserve":"","source":code}
    
    headers = {
        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.117 Safari/537.36",
        "referer": "https://pyob.oxyry.com/",
        "content-type": "application/json"
	}

    res = requests.post("https://pyob.oxyry.com/obfuscate", data=json.dumps(data), headers=headers)

    #

    text = res.text
    logging.debug(text)

    d = json.loads(text) 
    logging.debug(d)

    return d["dest"]

if __name__ == "__main__":
    import logging_lib
    #level = logging.DEBUG
    #level = logging.INFO
    level = logging.ERROR
    logging.basic_config(level)

    parser = argparse.ArgumentParser()
    parser.add_argument('--input')
    parser.add_argument('--output')
    args = parser.parse_args()
    input = args.input
    output = args.output
    logging.debug(input)
    logging.debug(output)
    logging.debug("----------")

    #code = "print('안녕하세요')"
    f = open(input, encoding='utf8')
    code = f.read() 
    f.close()

    obfuscated_code = obfuscate_code(code)
    logging.debug(obfuscated_code)

    #https://stackoverflow.com/questions/10149263/extract-a-part-of-the-filepath-a-directory-in-python
    p = Path(output)
    dir = str(p.parent)
    if not os.path.exists(dir):
        os.makedirs(dir)

    f = open(output, 'w', encoding='utf8')
    f.write(obfuscated_code)
    f.close()



def read_file(file):
    with open(file, encoding="utf8") as f:
        text = f.read()
    return text

def write_file(file, text):
    with open(file, "w", encoding="utf8") as f:
        f.write(text)


import logging as log
import sys

DEBUG = log.DEBUG
INFO = log.INFO
ERROR = log.ERROR

'''
level = python_supporter.logging.DEBUG
#level = python_supporter.logging.INFO
#level = python_supporter.logging.ERROR
python_supporter.logging.basic_config(level)
'''
def basic_config(level=DEBUG, log_file="log.txt"):
    for name in log.root.manager.loggerDict:
        logger = log.getLogger(name)
        #logger.disabled = True
        logger.setLevel(logging.ERROR)

    log.basicConfig(
        handlers=[
            log.FileHandler(log_file, encoding="utf-8"),
            log.StreamHandler(sys.stdout)
        ],
        format = '%(asctime)s: %(levelname)s: %(message)s',
        datefmt = '%Y-%m-%d %H:%M:%S',
        level = level
    )

    def debug(message):
        log.debug(message)
    
    def info(message):
        log.info(message)
        
    def error(message):
        log.error(message)
                
